validate_claim_token

Function validate_claim_token 

pub fn validate_claim_token(token: &str) -> Result<(), ClaimTokenError>
Validate a claim token format.

Errors

Returns a user-facing validation error when the token is empty, has the wrong prefix, or has the wrong length.